@@ -36,8 +36,8 @@ public:
 	void setComment(const QString &comment);
 
 protected:
-	bool preStart() Q_DECL_OVERRIDE;
-	bool nextLine(const QString &line) Q_DECL_OVERRIDE;
+	bool preStart() override;
+	bool nextLine(const QString &line) override;
 
 private:
 	QString m_name;
