@@ -25,7 +25,7 @@ class KGpgChangeDisable: public KGpgEditKeyTransaction {
 	Q_OBJECT
 
 	Q_DISABLE_COPY(KGpgChangeDisable)
-	KGpgChangeDisable() Q_DECL_EQ_DELETE;
+	KGpgChangeDisable() = delete;
 
 public:
 	KGpgChangeDisable(QObject *parent, const QString &keyid, const bool disable);
@@ -34,8 +34,8 @@ public:
 	void setDisable(bool disable);
 
 protected:
-	bool preStart() Q_DECL_OVERRIDE;
-	bool nextLine(const QString &line) Q_DECL_OVERRIDE;
+	bool preStart() override;
+	bool nextLine(const QString &line) override;
 };
 
 #endif // KGPGCHANGEDISABLE_H
