@@ -30,11 +30,11 @@ public:
 	virtual ~KGpgChangePass();
 
 protected:
-	bool nextLine(const QString &line) Q_DECL_OVERRIDE;
-	bool preStart() Q_DECL_OVERRIDE;
-	bool passphraseRequested() Q_DECL_OVERRIDE;
-	bool passphraseReceived() Q_DECL_OVERRIDE;
-	bool hintLine(const KGpgTransaction::ts_hintType hint, const QString & args) Q_DECL_OVERRIDE;
+	bool nextLine(const QString &line) override;
+	bool preStart() override;
+	bool passphraseRequested() override;
+	bool passphraseReceived() override;
+	bool hintLine(const KGpgTransaction::ts_hintType hint, const QString & args) override;
 
 private:
 	bool m_seenold;		///< old password correctly entered
