@@ -29,7 +29,7 @@ class KGpgSignUid: public KGpgUidTransaction, public KGpgSignTransactionHelper {
 	Q_OBJECT
 
 	Q_DISABLE_COPY(KGpgSignUid)
-	KGpgSignUid() Q_DECL_EQ_DELETE;
+	KGpgSignUid() = delete;
 
 public:
 	/**
@@ -60,13 +60,13 @@ public:
 	void setUid(const KGpgSignableNode *uid);
 
 protected:
-	bool preStart() Q_DECL_OVERRIDE;
-	bool nextLine(const QString &line) Q_DECL_OVERRIDE;
-	ts_boolanswer boolQuestion(const QString &line) Q_DECL_OVERRIDE;
-	bool passphraseReceived() Q_DECL_OVERRIDE;
+	bool preStart() override;
+	bool nextLine(const QString &line) override;
+	ts_boolanswer boolQuestion(const QString &line) override;
+	bool passphraseReceived() override;
 
-	KGpgTransaction *asTransaction() Q_DECL_OVERRIDE;
-	void replaceCmd(const QString &cmd) Q_DECL_OVERRIDE;
+	KGpgTransaction *asTransaction() override;
+	void replaceCmd(const QString &cmd) override;
 
 private:
 	int m_cmdPos;		///< position of the command in GnuPG command line
